@@ -4,13 +4,15 @@ import os
 import unittest
 from unittest import mock
 
+import respx
+
 from ctakesclient import client
 from ctakesclient.typesystem import Polarity
 
 from tests.test_resources import LoadResource
 
 
-class TestClient(unittest.TestCase):
+class TestClient(unittest.IsolatedAsyncioTestCase):
     """Test case for client cTAKES extraction"""
 
     @mock.patch.dict(os.environ, {"URL_CTAKES_REST": ""})
@@ -21,13 +23,20 @@ class TestClient(unittest.TestCase):
     def test_server_url_override(self):
         self.assertEqual(client.get_url_ctakes_rest(), "http://example.com:2002/blarg")
 
-    @mock.patch("ctakesclient.client.requests.post")
-    def test_simple_extract(self, mock_post):
+    @respx.mock
+    async def test_simple_extract(self):
         """Confirm that a call to extract() gives us the expected CtakesJSON object"""
-        mock_response = mock.MagicMock()
-        mock_response.json.return_value = LoadResource.PHYSICIAN_NOTE_JSON.value
-        mock_post.return_value = mock_response
-        ner = client.extract("input text does not matter")
+        sentence = "input text sentence"
+
+        # Prepare mocked response
+        respx.post(
+            "http://localhost:8080/ctakes-web-rest/service/analyze",
+            headers={"Content-Type": "text/plain; charset=UTF-8"},
+            content=sentence,
+        ).respond(json=LoadResource.PHYSICIAN_NOTE_JSON.value)
+
+        # Make the actual call
+        ner = await client.extract(sentence)
 
         # CtakesJSON is tested more fully in test_typesystem.py.
         # We just want to make sure that we did actually load the json here.
